Clojure only.

clj-infisical.http

Thin transport actions. This is the only namespace allowed to import clj-http-lite -- see doc/SPEC.md 5.3.

Thin transport actions. This is the only namespace allowed to import
clj-http-lite -- see doc/SPEC.md 5.3.
raw docstring

get-json!clj

(get-json! url query-params headers)

GETs url with query-params/headers. Never throws on a non-2xx status.

GETs url with query-params/headers. Never throws on a non-2xx status.
sourceraw docstring

post-json!clj

(post-json! url json-body-map)

POSTs json-body-map as a JSON body. Never throws on a non-2xx status -- callers decide what counts as an error, not clj-http-lite.

POSTs json-body-map as a JSON body. Never throws on a non-2xx status --
callers decide what counts as an error, not clj-http-lite.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries