Thin transport actions. This is the only namespace allowed to import clj-http-lite -- see doc/SPEC.md 5.3.
Thin transport actions. This is the only namespace allowed to import clj-http-lite -- see doc/SPEC.md 5.3.
(get-json! url query-params headers)GETs url with query-params/headers. Never throws on a non-2xx status.
GETs url with query-params/headers. Never throws on a non-2xx status.
(post-json! url json-body-map)POSTs json-body-map as a JSON body. Never throws on a non-2xx status -- callers decide what counts as an error, not clj-http-lite.
POSTs json-body-map as a JSON body. Never throws on a non-2xx status -- callers decide what counts as an error, not clj-http-lite.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |